//***********************************************************************
//		MonitorTest / AppWindow.cpp
//
//					Copyright (c) 2003 David Blumberg
//						davidblumberg@pixay.com
//					Published under the MIT license
//***********************************************************************

#include <Application.h>
#include "AppWindow.h"
#include "Const.h"


AppWindow::AppWindow(BRect frame)
		: BWindow(frame, "MonitorTest", B_BORDERED_WINDOW, B_NOT_RESIZABLE | B_NOT_ZOOMABLE)
{
	fMainView = new MainView(Bounds(), "Main View");
	AddChild(fMainView);
	
	fColorView = new ColorView(Bounds(), "Color View");
	fConvergenceView = new ConvergenceView(Bounds(), "Convergence View");
	fGeometryView = new GeometryView(Bounds(), "Geometry View");
	fMoireView = new MoireView(Bounds(), "Moire View");
	fReadabilityView = new ReadabilityView(Bounds(), "Readability View");
}

AppWindow::~AppWindow() {
}

bool AppWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return(true);
}

void AppWindow::MessageReceived(BMessage *message)
{
	switch(message->what)
	{
		case COLOR:
		{
			screenCount = 1;
			
			RemoveChild(fMainView);
			AddChild(fColorView);
		}
		break;
		case CONVERGENCE:
		{
			screenCount = 1;
			
			RemoveChild(fMainView);
			AddChild(fConvergenceView);
		}
		break;
		case GEOMETRY:
		{
			screenCount = 1;
			
			RemoveChild(fMainView);
			AddChild(fGeometryView);
		}
		break;
		case MOIRE:
		{
			screenCount = 1;
			
			RemoveChild(fMainView);
			AddChild(fMoireView);
		}
		break;
		case READABILITY:
		{
			screenCount = 1;
			
			RemoveChild(fMainView);
			AddChild(fReadabilityView);
		}
		break;
		
		case LEFT_CLICK:
		{
			screenCount++;
			
			message->FindInt32("screen_id", &screen_id);
			
			if(screen_id == 1) // Geometry
			{
				if(screenCount >= 5)
				{
					RemoveChild(fGeometryView);
					AddChild(fMainView);
				}
				else
					fGeometryView->Invalidate();
			}
			else if(screen_id == 2) // Color
			{
				if(screenCount >= 6)
				{
					RemoveChild(fColorView);
					AddChild(fMainView);
				}
				else
					fColorView->Invalidate();
			}
			else if(screen_id == 3) // Moire
			{
				if(screenCount >= 7)
				{
					RemoveChild(fMoireView);
					AddChild(fMainView);
				}
				else
					fMoireView->Invalidate();
			}
			else if(screen_id == 4) // Convergence
			{
				if(screenCount >= 5)
				{
					RemoveChild(fConvergenceView);
					AddChild(fMainView);
				}
				else
					fConvergenceView->Invalidate();
			}
			else if(screen_id == 5) // Readability
			{
				if(screenCount >= 3)
				{
					RemoveChild(fReadabilityView);
					AddChild(fMainView);
				}
				else
					fReadabilityView->Invalidate();
			}
		}
		break;
		case RIGHT_CLICK:
		{
			screenCount--;
			
			message->FindInt32("screen_id", &screen_id);
			
			if(screen_id == 1) // Geometry
			{
				if(screenCount <= 0)
				{
					RemoveChild(fGeometryView);
					AddChild(fMainView);
				}
				else
					fGeometryView->Invalidate();
			}
			else if(screen_id == 2) // Color
			{
				if(screenCount <= 0)
				{
					RemoveChild(fColorView);
					AddChild(fMainView);
				}
				else
					fColorView->Invalidate();
			}
			else if(screen_id == 3) // Moire
			{
				if(screenCount <= 0)
				{
					RemoveChild(fMoireView);
					AddChild(fMainView);
				}
				else
					fMoireView->Invalidate();
			}
			else if(screen_id == 4) // Convergence
			{
				if(screenCount <= 0)
				{
					RemoveChild(fConvergenceView);
					AddChild(fMainView);
				}
				else
					fConvergenceView->Invalidate();
			}
			else if(screen_id == 5) // Readability
			{
				if(screenCount <= 0)
				{
					RemoveChild(fReadabilityView);
					AddChild(fMainView);
				}
				else
					fReadabilityView->Invalidate();
			}
		}
		break;
		
		case MEDIA:
			be_roster->Launch("application/x-vnd.Be.MediaPrefs");
		break;
		case SCREEN:
			be_roster->Launch("application/x-vnd.Be-SCRN");
		break;
		case B_ABOUT_REQUESTED:
			(new BAlert("About", 
				"MonitorTest 0.2a\n\n"
				"Copyright (c) 2003 David Blumberg.\n"
				"davidblumberg@pixay.com\n\n"
				"Navigate the screens with the left and right mouse buttons.\n\n"
				"Note: MonitorTest does nothing to your monitor. It cannot harm or change any monitor related settings!", 
				"Cool"
				))->Go();
		break;
		case QUIT:
			QuitRequested();
		break;
		
		default:
			BWindow::MessageReceived(message);
		break;
	}
}
