//***********************************************************************
//		MonitorTest / GeometryView.cpp
//
//					Copyright (c) 2003 David Blumberg
//						davidblumberg@pixay.com
//					Published under the MIT license
//***********************************************************************

#include "AppWindow.h"
#include "GeometryView.h"
#include "Const.h"


GeometryView::GeometryView(BRect frame, const char *name, uint32 resizingMode = B_FOLLOW_ALL, uint32 flags = B_WILL_DRAW)
		: BView(frame, name, resizingMode, flags)
{
	SetViewColor(0,0,0);
	screenRect = fScreen.Frame();
}

GeometryView::~GeometryView() {
}

void GeometryView::Draw(BRect updateRect)
{
	if(fAppWindow->screenCount == 1)
	{
		SetHighColor(255,255,255);
		
		SetPenSize(1.0);
	
		// Draw frame
		StrokeRect(screenRect);
	
		// Draw x-axis pattern
		xCoord = screenRect.right / 16;
		xIncrease = xCoord;
		for(; xCoord < screenRect.right; xCoord += xIncrease)
		{
			StrokeLine(BPoint((xCoord), (screenRect.top)), BPoint((xCoord), (screenRect.bottom)));
		}
	
		// Draw y-axis pattern
		yCoord = screenRect.bottom / 12;
		yIncrease = yCoord;
		for(; yCoord < screenRect.bottom; yCoord += yIncrease)
		{
			StrokeLine(BPoint((screenRect.left), (yCoord)), BPoint((screenRect.right), (yCoord)));
		}
	
		// Draw center ellipse
		BRect cEllipseRect = fScreen.Frame();
		cEllipseRect.left += ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		cEllipseRect.right -= ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		StrokeEllipse(cEllipseRect);
	
		// Draw lefttop ellipse
		BRect ltEllipseRect = fScreen.Frame();
		ltEllipseRect.right = (ltEllipseRect.left + (screenRect.right / 16 * 2));
		ltEllipseRect.bottom = (ltEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(ltEllipseRect);
	
		// Draw righttop ellipse
		BRect rtEllipseRect = fScreen.Frame();
		rtEllipseRect.left = (rtEllipseRect.right - (screenRect.right / 16 * 2));
		rtEllipseRect.bottom = (rtEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(rtEllipseRect);
	
		// Draw leftbottom ellipse
		BRect lbEllipseRect = fScreen.Frame();
		lbEllipseRect.right = (lbEllipseRect.left + (screenRect.right / 16 * 2));
		lbEllipseRect.top = (lbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(lbEllipseRect);
	
		// Draw rightbottom ellipse
		BRect rbEllipseRect = fScreen.Frame();
		rbEllipseRect.left = (rbEllipseRect.right - (screenRect.right / 16 * 2));
		rbEllipseRect.top = (rbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(rbEllipseRect);
	}
	else if(fAppWindow->screenCount == 2)
	{
		SetHighColor(0,255,0);
		
		SetPenSize(1.0);
	
		// Draw frame
		StrokeRect(screenRect);
	
		// Draw x-axis pattern
		xCoord = screenRect.right / 16;
		xIncrease = xCoord;
		for(; xCoord < screenRect.right; xCoord += xIncrease)
		{
			StrokeLine(BPoint((xCoord), (screenRect.top)), BPoint((xCoord), (screenRect.bottom)));
		}
	
		// Draw y-axis pattern
		yCoord = screenRect.bottom / 12;
		yIncrease = yCoord;
		for(; yCoord < screenRect.bottom; yCoord += yIncrease)
		{
			StrokeLine(BPoint((screenRect.left), (yCoord)), BPoint((screenRect.right), (yCoord)));
		}
	
		// Draw center ellipse
		BRect cEllipseRect = fScreen.Frame();
		cEllipseRect.left += ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		cEllipseRect.right -= ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		StrokeEllipse(cEllipseRect);
	
		// Draw lefttop ellipse
		BRect ltEllipseRect = fScreen.Frame();
		ltEllipseRect.right = (ltEllipseRect.left + (screenRect.right / 16 * 2));
		ltEllipseRect.bottom = (ltEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(ltEllipseRect);
	
		// Draw righttop ellipse
		BRect rtEllipseRect = fScreen.Frame();
		rtEllipseRect.left = (rtEllipseRect.right - (screenRect.right / 16 * 2));
		rtEllipseRect.bottom = (rtEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(rtEllipseRect);
	
		// Draw leftbottom ellipse
		BRect lbEllipseRect = fScreen.Frame();
		lbEllipseRect.right = (lbEllipseRect.left + (screenRect.right / 16 * 2));
		lbEllipseRect.top = (lbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(lbEllipseRect);
	
		// Draw rightbottom ellipse
		BRect rbEllipseRect = fScreen.Frame();
		rbEllipseRect.left = (rbEllipseRect.right - (screenRect.right / 16 * 2));
		rbEllipseRect.top = (rbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(rbEllipseRect);
	}
	else if(fAppWindow->screenCount == 3)
	{
		SetHighColor(255,255,255);
		
		SetPenSize(1.0);
	
		// Draw frame
		StrokeRect(screenRect);
	
		// Draw x-axis pattern
		xCoord = screenRect.right / 32;
		xIncrease = xCoord;
		for(; xCoord < screenRect.right; xCoord += xIncrease)
		{
			StrokeLine(BPoint((xCoord), (screenRect.top)), BPoint((xCoord), (screenRect.bottom)));
		}
	
		// Draw y-axis pattern
		yCoord = screenRect.bottom / 24;
		yIncrease = yCoord;
		for(; yCoord < screenRect.bottom; yCoord += yIncrease)
		{
			StrokeLine(BPoint((screenRect.left), (yCoord)), BPoint((screenRect.right), (yCoord)));
		}
	
		// Draw center ellipse
		BRect cEllipseRect = fScreen.Frame();
		cEllipseRect.left += ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		cEllipseRect.right -= ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		StrokeEllipse(cEllipseRect);
	
		// Draw lefttop ellipse
		BRect ltEllipseRect = fScreen.Frame();
		ltEllipseRect.right = (ltEllipseRect.left + (screenRect.right / 16 * 2));
		ltEllipseRect.bottom = (ltEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(ltEllipseRect);
	
		// Draw righttop ellipse
		BRect rtEllipseRect = fScreen.Frame();
		rtEllipseRect.left = (rtEllipseRect.right - (screenRect.right / 16 * 2));
		rtEllipseRect.bottom = (rtEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(rtEllipseRect);
	
		// Draw leftbottom ellipse
		BRect lbEllipseRect = fScreen.Frame();
		lbEllipseRect.right = (lbEllipseRect.left + (screenRect.right / 16 * 2));
		lbEllipseRect.top = (lbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(lbEllipseRect);
	
		// Draw rightbottom ellipse
		BRect rbEllipseRect = fScreen.Frame();
		rbEllipseRect.left = (rbEllipseRect.right - (screenRect.right / 16 * 2));
		rbEllipseRect.top = (rbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(rbEllipseRect);
	}
	else if(fAppWindow->screenCount == 4)
	{
		SetHighColor(0,255,0);
		
		SetPenSize(1.0);
	
		// Draw frame
		StrokeRect(screenRect);
	
		// Draw x-axis pattern
		xCoord = screenRect.right / 32;
		xIncrease = xCoord;
		for(; xCoord < screenRect.right; xCoord += xIncrease)
		{
			StrokeLine(BPoint((xCoord), (screenRect.top)), BPoint((xCoord), (screenRect.bottom)));
		}
	
		// Draw y-axis pattern
		yCoord = screenRect.bottom / 24;
		yIncrease = yCoord;
		for(; yCoord < screenRect.bottom; yCoord += yIncrease)
		{
			StrokeLine(BPoint((screenRect.left), (yCoord)), BPoint((screenRect.right), (yCoord)));
		}
	
		// Draw center ellipse
		BRect cEllipseRect = fScreen.Frame();
		cEllipseRect.left += ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		cEllipseRect.right -= ((cEllipseRect.right - cEllipseRect.bottom) / 2);
		StrokeEllipse(cEllipseRect);
	
		// Draw lefttop ellipse
		BRect ltEllipseRect = fScreen.Frame();
		ltEllipseRect.right = (ltEllipseRect.left + (screenRect.right / 16 * 2));
		ltEllipseRect.bottom = (ltEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(ltEllipseRect);
	
		// Draw righttop ellipse
		BRect rtEllipseRect = fScreen.Frame();
		rtEllipseRect.left = (rtEllipseRect.right - (screenRect.right / 16 * 2));
		rtEllipseRect.bottom = (rtEllipseRect.top + (screenRect.bottom / 12 * 2));
		StrokeEllipse(rtEllipseRect);
	
		// Draw leftbottom ellipse
		BRect lbEllipseRect = fScreen.Frame();
		lbEllipseRect.right = (lbEllipseRect.left + (screenRect.right / 16 * 2));
		lbEllipseRect.top = (lbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(lbEllipseRect);
	
		// Draw rightbottom ellipse
		BRect rbEllipseRect = fScreen.Frame();
		rbEllipseRect.left = (rbEllipseRect.right - (screenRect.right / 16 * 2));
		rbEllipseRect.top = (rbEllipseRect.bottom - (screenRect.bottom / 12 * 2));
		StrokeEllipse(rbEllipseRect);
	}
}

void GeometryView::MouseDown(BPoint where)
{
	Window()->Activate();
	
	if(Window()->CurrentMessage()->FindInt32("buttons") == B_PRIMARY_MOUSE_BUTTON)
	{
		BMessage LeftClick(LEFT_CLICK);
		LeftClick.AddInt32("screen_id", 1);
		Window()->PostMessage(&LeftClick);
	}	
	else if(Window()->CurrentMessage()->FindInt32("buttons") == B_SECONDARY_MOUSE_BUTTON)
	{
		BMessage RightClick(RIGHT_CLICK);
		RightClick.AddInt32("screen_id", 1);
		Window()->PostMessage(&RightClick);
	}
}
